@@ -14,15 +14,13 @@ from django.utils.safestring import mark_safe
 from ajax_model_listing.settings import AJAX_LIST_SETTINGS
 
 
-DEFAULT_PER_PAGE = 12
-
-
 # ===== FIELDS HELPERS =====
 
 default_field = lambda: {
     'th_tag_attrs': {'class': 'ajax_list_header'},
     'td_tag_attrs': lambda instance: {'class': 'ajax_list_value'},
     'column_title': None,
+    'escape_title': True,
     'display_value': None,
     'escape_display': True,
     'link': True,
@@ -123,12 +121,15 @@ class AjaxList(object):
             after_paginate = None,
             url = None,
             new_tab = True,
-            per_page = DEFAULT_PER_PAGE,
-            table_tag_attrs = {},
+            per_page = AJAX_LIST_SETTINGS['per_page'],
+            table_tag_attrs = AJAX_LIST_SETTINGS['table_tag_attrs'],
             tr_tag_attrs = lambda instance: {},
             filter_form = None,
-            custom_table_foot_template = None,
-            show_records_count = None
+            table_foot_template = AJAX_LIST_SETTINGS['table_foot_template'],
+            show_records_count = AJAX_LIST_SETTINGS['show_records_count'],
+            sort_icon_default = AJAX_LIST_SETTINGS['sort_icon_default'],
+            sort_icon_asc = AJAX_LIST_SETTINGS['sort_icon_asc'],
+            sort_icon_desc = AJAX_LIST_SETTINGS['sort_icon_desc'],
         ):
         
         # ===== SET INSTANCE PROPERTIES =====
@@ -163,8 +164,11 @@ class AjaxList(object):
         self.per_page = per_page
         self.table_tag_attrs = table_tag_attrs
         self.tr_tag_attrs = tr_tag_attrs
-        self.custom_table_foot_template = custom_table_foot_template
-        self.show_records_count = show_records_count or AJAX_LIST_SETTINGS['SHOW_RECORDS_COUNT']
+        self.table_foot_template = table_foot_template
+        self.show_records_count = show_records_count
+        self.sort_icon_default = sort_icon_default
+        self.sort_icon_asc = sort_icon_asc
+        self.sort_icon_desc = sort_icon_desc
         
         # ===== PAGINATE QUERYSET =====
         self.paginator = Paginator(self.queryset, self.per_page)
@@ -238,20 +242,18 @@ class AjaxList(object):
         context = {
             'fields_count': len(self.fields),
             'page': self.page,
-            'PAGE_FIRST_ELEMENT': AJAX_LIST_SETTINGS['PAGE_FIRST_ELEMENT'],
-            'PAGE_PREVIOUS_ELEMENT': AJAX_LIST_SETTINGS['PAGE_PREVIOUS_ELEMENT'],
-            'PAGE_NEXT_ELEMENT': AJAX_LIST_SETTINGS['PAGE_NEXT_ELEMENT'],
-            'PAGE_LAST_ELEMENT': AJAX_LIST_SETTINGS['PAGE_LAST_ELEMENT'],
-            'SHOW_RECORDS_COUNT': self.show_records_count,
+            'show_records_count': self.show_records_count,
         }
-        foot_template = self.custom_table_foot_template or 'ajax_model_listing/list_foot.html'
-        return render_to_response(foot_template, context).content
+        return render_to_response(self.table_foot_template, context).content
     
     
     def __unicode__(self):
         context = {
             'STATIC_URL': settings.STATIC_URL,
             'table_attrs': create_table_attrs(self.table_tag_attrs),
+            'sort_icon_default': self.sort_icon_default,
+            'sort_icon_asc': self.sort_icon_asc,
+            'sort_icon_desc': self.sort_icon_desc,
             'thead': self.head(),
             'tfoot': self.body(),
             'tbody': self.foot(),
